# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .tags import (
    TagsResource,
    AsyncTagsResource,
    TagsResourceWithRawResponse,
    AsyncTagsResourceWithRawResponse,
    TagsResourceWithStreamingResponse,
    AsyncTagsResourceWithStreamingResponse,
)
from .certs import (
    CertsResource,
    AsyncCertsResource,
    CertsResourceWithRawResponse,
    AsyncCertsResourceWithRawResponse,
    CertsResourceWithStreamingResponse,
    AsyncCertsResourceWithStreamingResponse,
)

__all__ = [
    "TagsResource",
    "AsyncTagsResource",
    "TagsResourceWithRawResponse",
    "AsyncTagsResourceWithRawResponse",
    "TagsResourceWithStreamingResponse",
    "AsyncTagsResourceWithStreamingResponse",
    "CertsResource",
    "AsyncCertsResource",
    "CertsResourceWithRawResponse",
    "AsyncCertsResourceWithRawResponse",
    "CertsResourceWithStreamingResponse",
    "AsyncCertsResourceWithStreamingResponse",
]







  



from __future__ import annotations

from typing import Optional
from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["HighlvlvpcRetrieveVpcParams"]


class HighlvlvpcRetrieveVpcParams(TypedDict, total=False):
    k_customer_id: Required[Annotated[str, PropertyInfo(alias="k-customer-id")]]

    x_account_id: Required[Annotated[str, PropertyInfo(alias="x-account-id")]]

    vpc_id: Optional[str]
    """The KRN of the VPC to retrieve."""

    vpc_name: Optional[str]
    """The name of the VPC to retrieve."""



# python
import os
from dotenv import load_dotenv
from krutrim_client import KrutrimClient 

load_dotenv()
api_key = os.getenv("API_KEY")

client = KrutrimClient(api_key=api_key)

try:
    lb_krn="enter the load balancer krn"
    resp = client.lb.with_raw_response.update_load_balancer(

        path_lb_krn=lb_krn,
        x_region="enter the x_region",
        # x_region possible values "In-Bangalore-1"
        k_customer_id="enter the k_customer_id",
        x_account_id="enter the x_account_id",
        listeners=[],
        loadbalancer_data={

        },
        security_groups=[],
    )
    print(resp.status_code, resp.text)
except Exception as e:
    print(f"Error has occurred: {e}")



            # {
            #     "listener_data": {
            #         "listener_id": "6193a5b8-c25a-4979-948b-c7176bf4a343",
            #         "listener_index": 1,
            #         "listener_name": "web-listener",
            #         "protocol": "HTTP",
            #         "protocol_port": 80,
            #     },
            #     "policy_data": [
            #         {
            #             "action": "REDIRECT_TO_POOL",
            #             "policy_id": "6a588b1f-3b81-40fa-b7be-63a090e1f75a",
            #             "policy_name": "test-lb-1-policy-1",
            #             "rule_data": [
            #                 {
            #                     "compare_type": "STARTS_WITH",
            #                     "key": "",
            #                     "rule_id": "c1f3cc38-4258-43e3-9a1f-035666390fbc",
            #                     "rule_krn": "krn:loadbalancer-service:In-Bangalore-1:7344783839:2fbf2544-0c1d-481c-b745-4ef99e564b41:rule:72797759-8b8a-4b03-b2ec-bd1799999e62",
            #                     "type": "PATH",
            #                     "value": "/",
            #                 }
            #             ],
            #         }
            #     ],
            #     "pool_data": [
            #         {
            #             "admin_state_up": True,
            #             "healthmonitor_data": {
            #                 "delay": 10,
            #                 "h_type": "HTTP",
            #                 "health_monitor_id": "6bd47474-a10b-457f-a682-3da894c41ee4",
            #                 "max_retries": 3,
            #                 "name": "tg_testing_15th_oct",
            #                 "timeout": 5,
            #                 "url_path": "/",
            #             },
            #             "lb_algorithm": "ROUND_ROBIN",
            #             "member_data": [
            #                 {
            #                     "krn": "krn:loadbalancer-service:In-Bangalore-1:7344783839:2fbf2544-0c1d-481c-b745-4ef99e564b41:member:1f4d2055-559c-4e22-836c-82aba5113996",
            #                     "member_id": "2ce57b22-ef8b-4ca7-b1af-b32e2a753206",
            #                     "member_index": 1,
            #                     "status": "success",
            #                 },
            #                 {
            #                     "krn": "krn:loadbalancer-service:In-Bangalore-1:7344783839:2fbf2544-0c1d-481c-b745-4ef99e564b41:member:90bce6ed-f757-4c15-8e31-5b8f08fb7d57",
            #                     "member_id": "a512e1f9-5382-49f3-b35e-43d824d54135",
            #                     "member_index": 2,
            #                     "status": "success",
            #                 },
            #             ],
            #             "pool_id": "0c0b62ad-084d-4f1f-b3ce-8763229208e0",
            #             "pool_name": "test-lb-1-pool-1",
            #             "protocol": "HTTP",
            #             "target_group_name": "lb_apr_22_release_testing_TG",
            #         }
            #     ],
            # }



            # "create_port": True,
            # "description": "",
            # "floating_ip": False,
            # "lb_name": "test-lb-1",
            # "network_id": "krn:vpc:In-Bangalore-1:7344783839:2fbf2544-0c1d-481c-b745-4ef99e564b41:network:aea55436-84b9-4d08-87d1-8cc831ed2811",
            # "vip_subnet_id": "krn:vpc:In-Bangalore-1:7344783839:2fbf2544-0c1d-481c-b745-4ef99e564b41:subnet:15aaac4e-fc29-4c26-8283-d5ed1824ba85",
            # "vpc_id": "krn:vpc:In-Bangalore-1:7344783839:2fbf2544-0c1d-481c-b745-4ef99e564b41:vpc:0f716d62-fe5d-4aff-b23e-a277192b3546",            


# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["TagListParams"]


class TagListParams(TypedDict, total=False):
    cert_id: Required[Annotated[str, PropertyInfo(alias="certId")]]

    tag_name: Required[Annotated[str, PropertyInfo(alias="tagName")]]


from typing import Optional

from pydantic import Field as FieldInfo


from krutrim_client._models import BaseModel

__all__ = ["AccessKeyCreateResponse"]


class AccessKeyCreateResponse(BaseModel):
    access_key: Optional[str] = FieldInfo(alias="access_key", default=None)
    """The generated access key ID."""

    message: Optional[str] = None

    secret_key: Optional[str] = FieldInfo(alias="secret_key", default=None)
    """The generated secret access key."""



import os
import json
from dotenv import load_dotenv
from krutrim_client import KrutrimClient


load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)

try:
    kpod_krn = "enter the pod krn"

    if kpod_krn:
        delete_pod_resp = client.kpod.pod.delete(kpod_krn)
        print(f"Pod with ID {kpod_krn} has been deleted successfully.")
    else:
        print(f"Pod with ID {kpod_krn} not found.")
except Exception as e:
    print(f"Error occurred: {e}")





from typing import Optional

from ..._models import BaseModel

__all__ = ["V1CreateRuleResponse"]


class V1CreateRuleResponse(BaseModel):
    id: Optional[str] = None
    """The UUID of the newly created Security Group Rule."""

    message: Optional[str] = None
    """A confirmation message."""

    status: Optional[str] = None
    """The status of the rule (e.g., 'active', 'creating')."""



from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["CertGetExpiringParams"]


class CertGetExpiringParams(TypedDict, total=False):
    date: Required[str]

    vpc_id: Required[Annotated[str, PropertyInfo(alias="vpcId")]]


from .kos import (
    KosResource,
    AsyncKosResource,
    KosResourceWithRawResponse,
    AsyncKosResourceWithRawResponse,
    KosResourceWithStreamingResponse,
    AsyncKosResourceWithStreamingResponse,
)

from .buckets import (
    BucketsResource,
    AsyncBucketsResource,
    BucketsResourceWithRawResponse,
    AsyncBucketsResourceWithRawResponse,
    BucketsResourceWithStreamingResponse,
    AsyncBucketsResourceWithStreamingResponse,
)

from .accessKeys import (
    AccessKeysResource,
    AsyncAccessKeysResource,
    AccessKeysResourceWithRawResponse,
    AsyncAccessKeysResourceWithRawResponse,
    AccessKeysResourceWithStreamingResponse,
    AsyncAccessKeysResourceWithStreamingResponse,
)


__all__ = [
    "KosResource",
    "AsyncKosResource",
    "KosResourceWithRawResponse",
    "AsyncKosResourceWithRawResponse",
    "KosResourceWithStreamingResponse",
    "AsyncKosResourceWithStreamingResponse",
    "BucketsResource",
    "AsyncBucketsResource",
    "BucketsResourceWithRawResponse",
    "AsyncBucketsResourceWithRawResponse",
    "BucketsResourceWithStreamingResponse",
    "AsyncBucketsResourceWithStreamingResponse",
    "AccessKeysResource",
    "AsyncAccessKeysResource",
    "AccessKeysResourceWithRawResponse",
    "AsyncAccessKeysResourceWithRawResponse",
    "AccessKeysResourceWithStreamingResponse",
    "AsyncAccessKeysResourceWithStreamingResponse",
    
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .addons import (
    AddonsResource,
    AsyncAddonsResource,
    AddonsResourceWithRawResponse,
    AsyncAddonsResourceWithRawResponse,
    AddonsResourceWithStreamingResponse,
    AsyncAddonsResourceWithStreamingResponse,
)
from ...._types import Body, Omit, Query, Headers, NoneType, NotGiven, omit, NOT_GIVEN
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from .node_groups import (
    NodeGroupsResource,
    AsyncNodeGroupsResource,
    NodeGroupsResourceWithRawResponse,
    AsyncNodeGroupsResourceWithRawResponse,
    NodeGroupsResourceWithStreamingResponse,
    AsyncNodeGroupsResourceWithStreamingResponse,
)
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ....types.kks import cluster_create_params, cluster_upgrade_params
from ...._base_client import make_request_options

__all__ = ["ClustersResource", "AsyncClustersResource"]


class ClustersResource(SyncAPIResource):
    @cached_property
    def node_groups(self) -> NodeGroupsResource:
        return NodeGroupsResource(self._client)

    @cached_property
    def addons(self) -> AddonsResource:
        return AddonsResource(self._client)

    @cached_property
    def with_raw_response(self) -> ClustersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/kks-python#accessing-raw-response-data-eg-headers
        """
        return ClustersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ClustersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/kks-python#with_streaming_response
        """
        return ClustersResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        vpcKrn: str,
        subnetKrns: str,
        podIpv4Cidr: str,
        serviceIpv4Cidr:str,
        name: str | Omit = omit,
        version: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Create Cluster

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/v1/kks/clusters",
            body=maybe_transform(
                {
                    "resourcesVpcConfig": {
                        "vpcKrn":vpcKrn,
                        "subnetKrns":subnetKrns
                    },
                    "name": name,
                    "kubernetesNetworkConfig": {
                        "podIpv4Cidr":podIpv4Cidr,
                        "serviceIpv4Cidr":serviceIpv4Cidr
                    },
                    "version": version,
                },
                cluster_create_params.ClusterCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def retrieve(
        self,
        cluster_krn: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Cluster by Cluster KRN

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not cluster_krn:
            raise ValueError(f"Expected a non-empty value for `cluster_krn` but received {cluster_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            f"/v1/kks/clusters/{cluster_krn}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Get ALL clusters"""
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            "/v1/kks/clusters",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def delete(
        self,
        cluster_krn: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Delete cluster

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not cluster_krn:
            raise ValueError(f"Expected a non-empty value for `cluster_krn` but received {cluster_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/v1/kks/clusters/{cluster_krn}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def retrieve_kubeconfig(
        self,
        cluster_krn: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Retrieve kubeconfig

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not cluster_krn:
            raise ValueError(f"Expected a non-empty value for `cluster_krn` but received {cluster_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            f"/v1/kks/clusters/{cluster_krn}/kubeconfig",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def upgrade(
        self,
        cluster_krn: str,
        *,
        version: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Upgrade cluster

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not cluster_krn:
            raise ValueError(f"Expected a non-empty value for `cluster_krn` but received {cluster_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            f"/v1/kks/clusters/{cluster_krn}/updates",
            body=maybe_transform({"version": version}, cluster_upgrade_params.ClusterUpgradeParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncClustersResource(AsyncAPIResource):
    @cached_property
    def node_groups(self) -> AsyncNodeGroupsResource:
        return AsyncNodeGroupsResource(self._client)

    @cached_property
    def addons(self) -> AsyncAddonsResource:
        return AsyncAddonsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncClustersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/kks-python#accessing-raw-response-data-eg-headers
        """
        return AsyncClustersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncClustersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/kks-python#with_streaming_response
        """
        return AsyncClustersResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        vpcKrn: str,
        subnetKrns: str,
        podIpv4Cidr: str,
        serviceIpv4Cidr:str,
        name: str | Omit = omit,
        version: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Create Cluster

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/v1/kks/clusters",
            body=await async_maybe_transform(
                {
                    "resourcesVpcConfig": {
                        "vpcKrn":vpcKrn,
                        "subnetKrns":subnetKrns
                    },
                    "name": name,
                    "kubernetesNetworkConfig": {
                        "podIpv4Cidr":podIpv4Cidr,
                        "serviceIpv4Cidr":serviceIpv4Cidr
                    },
                    "version": version,
                },
                cluster_create_params.ClusterCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def retrieve(
        self,
        cluster_krn: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Cluster by Cluster KRN

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not cluster_krn:
            raise ValueError(f"Expected a non-empty value for `cluster_krn` but received {cluster_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            f"/v1/kks/clusters/{cluster_krn}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Get ALL clusters"""
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/v1/kks/clusters",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def delete(
        self,
        cluster_krn: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Delete cluster

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not cluster_krn:
            raise ValueError(f"Expected a non-empty value for `cluster_krn` but received {cluster_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/v1/kks/clusters/{cluster_krn}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def retrieve_kubeconfig(
        self,
        cluster_krn: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Retrieve kubeconfig

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not cluster_krn:
            raise ValueError(f"Expected a non-empty value for `cluster_krn` but received {cluster_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            f"/v1/kks/clusters/{cluster_krn}/kubeconfig",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def upgrade(
        self,
        cluster_krn: str,
        *,
        version: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Upgrade cluster

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not cluster_krn:
            raise ValueError(f"Expected a non-empty value for `cluster_krn` but received {cluster_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            f"/v1/kks/clusters/{cluster_krn}/updates",
            body=await async_maybe_transform({"version": version}, cluster_upgrade_params.ClusterUpgradeParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class ClustersResourceWithRawResponse:
    def __init__(self, clusters: ClustersResource) -> None:
        self._clusters = clusters

        self.create = to_raw_response_wrapper(
            clusters.create,
        )
        self.retrieve = to_raw_response_wrapper(
            clusters.retrieve,
        )
        self.list = to_raw_response_wrapper(
            clusters.list,
        )
        self.delete = to_raw_response_wrapper(
            clusters.delete,
        )
        self.retrieve_kubeconfig = to_raw_response_wrapper(
            clusters.retrieve_kubeconfig,
        )
        self.upgrade = to_raw_response_wrapper(
            clusters.upgrade,
        )

    @cached_property
    def node_groups(self) -> NodeGroupsResourceWithRawResponse:
        return NodeGroupsResourceWithRawResponse(self._clusters.node_groups)

    @cached_property
    def addons(self) -> AddonsResourceWithRawResponse:
        return AddonsResourceWithRawResponse(self._clusters.addons)


class AsyncClustersResourceWithRawResponse:
    def __init__(self, clusters: AsyncClustersResource) -> None:
        self._clusters = clusters

        self.create = async_to_raw_response_wrapper(
            clusters.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            clusters.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            clusters.list,
        )
        self.delete = async_to_raw_response_wrapper(
            clusters.delete,
        )
        self.retrieve_kubeconfig = async_to_raw_response_wrapper(
            clusters.retrieve_kubeconfig,
        )
        self.upgrade = async_to_raw_response_wrapper(
            clusters.upgrade,
        )

    @cached_property
    def node_groups(self) -> AsyncNodeGroupsResourceWithRawResponse:
        return AsyncNodeGroupsResourceWithRawResponse(self._clusters.node_groups)

    @cached_property
    def addons(self) -> AsyncAddonsResourceWithRawResponse:
        return AsyncAddonsResourceWithRawResponse(self._clusters.addons)


class ClustersResourceWithStreamingResponse:
    def __init__(self, clusters: ClustersResource) -> None:
        self._clusters = clusters

        self.create = to_streamed_response_wrapper(
            clusters.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            clusters.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            clusters.list,
        )
        self.delete = to_streamed_response_wrapper(
            clusters.delete,
        )
        self.retrieve_kubeconfig = to_streamed_response_wrapper(
            clusters.retrieve_kubeconfig,
        )
        self.upgrade = to_streamed_response_wrapper(
            clusters.upgrade,
        )

    @cached_property
    def node_groups(self) -> NodeGroupsResourceWithStreamingResponse:
        return NodeGroupsResourceWithStreamingResponse(self._clusters.node_groups)

    @cached_property
    def addons(self) -> AddonsResourceWithStreamingResponse:
        return AddonsResourceWithStreamingResponse(self._clusters.addons)


class AsyncClustersResourceWithStreamingResponse:
    def __init__(self, clusters: AsyncClustersResource) -> None:
        self._clusters = clusters

        self.create = async_to_streamed_response_wrapper(
            clusters.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            clusters.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            clusters.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            clusters.delete,
        )
        self.retrieve_kubeconfig = async_to_streamed_response_wrapper(
            clusters.retrieve_kubeconfig,
        )
        self.upgrade = async_to_streamed_response_wrapper(
            clusters.upgrade,
        )

    @cached_property
    def node_groups(self) -> AsyncNodeGroupsResourceWithStreamingResponse:
        return AsyncNodeGroupsResourceWithStreamingResponse(self._clusters.node_groups)

    @cached_property
    def addons(self) -> AsyncAddonsResourceWithStreamingResponse:
        return AsyncAddonsResourceWithStreamingResponse(self._clusters.addons)



from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key = api_key)

try: 
    delete_image_resp = client.highlvlvpc.delete_image(
        snapshot_krn = "enter the snapshot_krn",
        
    )

    print(f"Successfully delete for the snapshot_krn")
except Exception as e:
    print(f"Exception has occured: {e}")


# highlvlvpc_delete_image_response.py
from __future__ import annotations
from ..._models import BaseModel

__all__ = ["HighlvlvpcDeleteImageResponse"]

class HighlvlvpcDeleteImageResponse(BaseModel):
    success: bool
    """Whether the image deletion was successful."""

    message: str
    """A descriptive message about the deletion result."""



import os
from dotenv import load_dotenv
from krutrim_client import KrutrimClient
from krutrim_client.types.asg import VolumeParam
from krutrim_client.types.asg import PolicyParam


load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)

try:

     update_template = client.asg.v1.with_raw_response.update_launch_template(
        template_id="8eea5e0e-f843-11f0-b963-6e89ceb8bb39",
        template_name="templ345w54",

        instance_name="templ5644",
        instance_type="CPU-2x-8GB",
        sshkey_name="jawakey",
        # user_data="Enter an executable boot time command ex: #!bash sdk.sh",

        image_krn="krn:vm:In-Bangalore-1:default:default:image:498a1efb-4ca4-482b-bb5c-a51660f94215",

        security_groups=[
            "krn:sg:In-Bangalore-1:6419347276:df18aa35-b845-4e61-b739-32a3a4e219d3:sg:12345678-1234-1234-1234-123456789012",
            # "Enter the security group KRN ID 2 and so on",
        ],

        min=4,   #Enter the minimum instance count
        max=6,   #Enter the maximum instance count
        volume_name="vol09i8u23",
        volume_type="HNSS",
        volume_size=[
            VolumeParam(
                count=1,         #Enter the Volume Count
                volume_size=28,  #Enter the Volume Size
            ),
            # VolumeParam(
            #     count=1,
            #     volume_size=20,
            # ),
            # and add so on for multiple volumes selection
        ],

        policy=[
            PolicyParam(
                predefined_metric_specification={
                    "PredefinedMetricType": "AverageCPUUtilization"
                },
                up_scale_target_value=90,     #Enter the up scale target value
                down_scale_target_value=20,   #Enter the down scale target value
                scale_out_cooldown=10,        #Enter the scale out cooldown time in sec
                scale_in_cooldown=10,         #Enter the scale in cooldown time in sec
            ),

            # Scheduled
            PolicyParam(
                predefined_metric_type="PutScheduledAction",
                up_scale_time="06:00:00.000000",
                down_scale_time="10:00:00.000000",
            )
        ],
     )



     print(f"Template updated successfully : {update_template.json()}")

except Exception as e:
    print(f"Error has occurred: {e}")


from __future__ import annotations

from typing import Iterable
from typing_extensions import Required, TypedDict

__all__ = ["PodCreateParams"]


class PodCreateParams(TypedDict, total=False):
    container_disk_size: Required[str]
    """The size of the container disk in GB."""

    expose_http_ports: Required[str]
    """Comma-separated list of HTTP ports to expose (e.g., "8888")."""

    expose_tcp_ports: Required[str]
    """Comma-separated list of TCP ports to expose (e.g., "22")."""

    flavor_name: Required[str]
    """The name of the flavor/instance type for the pod (e.g., GPU type)."""

    has_encrypt_volume: Required[bool]
    """Indicates if the volume should be encrypted."""

    has_jupyter_notebook: Required[bool]
    """Indicates if Jupyter Notebook should be enabled."""

    has_ssh_access: Required[bool]
    """Indicates if SSH access should be enabled."""

    pod_name: Required[str]
    """Unique name for the pod."""

    pod_template_id: Required[int]
    """The ID of the pod template to use."""

    region: Required[str]
    """The region where the pod should be deployed."""

    sshkey_name: Required[str]
    """The name of the SSH key to associate with the pod."""

    volume_disk_size: Required[str]
    """The size of the attached volume disk in GB."""

    volume_mount_path: Required[str]
    """The path where the volume should be mounted inside the pod."""

    environment_variables: Iterable[object]
    """List of environment variables to set in the pod."""



from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()

api_key = os.getenv("api_key")

client = KrutrimClient(api_key = api_key)


try:
    GetVPC_List_resp = client.highlvlvpc.list_vpcs(
        x_region = "Enter the region",
        # x_region possible values "In-Bangalore-1","In-Hyderabad-1"
    )

    print(f"Successfully Executed {GetVPC_List_resp}")

except Exception as e:
    print(f"Error {e}")


# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable

import httpx

from ..._types import Body, Omit, Query, Headers, NoneType, NotGiven, omit, NOT_GIVEN
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.dns.v1 import record_create_params, record_update_params

__all__ = ["RecordResource", "AsyncRecordResource"]


class RecordResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> RecordResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/dns-6-python#accessing-raw-response-data-eg-headers
        """
        return RecordResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> RecordResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/dns-6-python#with_streaming_response
        """
        return RecordResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        krnid: str | Omit = omit,
        value: str,
        rname: str | Omit = omit,
        ttl: int | Omit = omit,
        TYPE: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Add DNS Record

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/dns/v1/record",
            body=maybe_transform(
                {
                    "krnid": krnid,
                    "records": [
                        {
                            "value":value
                        }
                    ],
                    "rname": rname,
                    "ttl": ttl,
                    "type": TYPE,
                },
                record_create_params.RecordCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def update(
        self,
        recordid: str,
        rname: str,
        *,
        records: Iterable[record_update_params.Record] | Omit = omit,
        value: str | Omit = omit,
        routing: str | Omit = omit,
        TYPE: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Update Record

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._put(
            f"/dns/v1/record/{recordid}",
            body=maybe_transform(
                {
                    "records": [
                        {
                            "value":value
                        }
                    ],
                    "rname": rname,
                    "routing": routing,
                    "type": TYPE,
                },
                record_update_params.RecordUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def delete(
        self,
        recordid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Delete Record

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not recordid:
            raise ValueError(f"Expected a non-empty value for `recordid` but received {recordid!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/dns/v1/record/{recordid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


    def fetchrecord(
        self,
        zoneid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Delete Record

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zoneid:
            raise ValueError(f"Expected a non-empty value for `zoneid` but received {zoneid!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            f"/dns/v1/records/{zoneid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

class AsyncRecordResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncRecordResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/dns-6-python#accessing-raw-response-data-eg-headers
        """
        return AsyncRecordResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncRecordResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/dns-6-python#with_streaming_response
        """
        return AsyncRecordResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        krnid: str | Omit = omit,
        value: str,
        rname: str | Omit = omit,
        routing: str | Omit = omit,
        ttl: int | Omit = omit,
        TYPE: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Add DNS Record

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/dns/v1/record",
            body=await async_maybe_transform(
                {
                    "krnid": krnid,
                    "records": [
                        {
                            "value":value
                        }
                    ],
                    "rname": rname,
                    "routing": routing,
                    "ttl": ttl,
                    "type": TYPE,
                },
                record_create_params.RecordCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def update(
        self,
        recordid: str,
        rname: str,
        *,
        records: Iterable[record_update_params.Record] | Omit = omit,
        value: str | Omit = omit,
        routing: str | Omit = omit,
        TYPE: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Update Record

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._put(
            f"/dns/v1/record/{recordid}",
            body=await async_maybe_transform(
                {
                    "records": records,
                    "rname": rname,
                    "routing": routing,
                    "type": TYPE,
                },
                record_update_params.RecordUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def delete(
        self,
        recordid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Delete Record

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not recordid:
            raise ValueError(f"Expected a non-empty value for `recordid` but received {recordid!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/dns/v1/record/{recordid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )



    async def fetchrecord(
        self,
        zoneid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Delete Record

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zoneid:
            raise ValueError(f"Expected a non-empty value for `zoneid` but received {zoneid!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            f"/dns/v1/records/{zoneid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

class RecordResourceWithRawResponse:
    def __init__(self, record: RecordResource) -> None:
        self._record = record

        self.create = to_raw_response_wrapper(
            record.create,
        )
        self.update = to_raw_response_wrapper(
            record.update,
        )
        self.delete = to_raw_response_wrapper(
            record.delete,
        )
        self.fetchrecord = to_raw_response_wrapper(
            record.fetchrecord,
        )

class AsyncRecordResourceWithRawResponse:
    def __init__(self, record: AsyncRecordResource) -> None:
        self._record = record

        self.create = async_to_raw_response_wrapper(
            record.create,
        )
        self.update = async_to_raw_response_wrapper(
            record.update,
        )
        self.delete = async_to_raw_response_wrapper(
            record.delete,
        )
        self.fetchrecord = async_to_raw_response_wrapper(
            record.fetchrecord,
        )

class RecordResourceWithStreamingResponse:
    def __init__(self, record: RecordResource) -> None:
        self._record = record

        self.create = to_streamed_response_wrapper(
            record.create,
        )
        self.update = to_streamed_response_wrapper(
            record.update,
        )
        self.delete = to_streamed_response_wrapper(
            record.delete,
        )
        self.fetchrecord = to_streamed_response_wrapper(
            record.fetchrecord,
        )


class AsyncRecordResourceWithStreamingResponse:
    def __init__(self, record: AsyncRecordResource) -> None:
        self._record = record

        self.create = async_to_streamed_response_wrapper(
            record.create,
        )
        self.update = async_to_streamed_response_wrapper(
            record.update,
        )
        self.delete = async_to_streamed_response_wrapper(
            record.delete,
        )
        self.fetchrecord = async_to_streamed_response_wrapper(
            record.fetchrecord,
        )



from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)

try:
    
    update_record = client.v1.record.update(
        rname="enter the record name",
        value="enter the value",  #10.10.10.123
        TYPE="A", #enter as per requirement
        routing="enter routing type", #example: "SIMPLE"
        recordid="entet the record_id",
    )

    print(f"Successfully updated the record: {update_record}")

except Exception as e:
    print(f"Exception: {e}")



from typing import Optional

from ..._models import BaseModel

__all__ = ["PodUpdateResponse"]


class PodUpdateResponse(BaseModel):
    message: Optional[str] = None

    status: Optional[str] = None



import os
from krutrim_client import KrutrimClient
from dotenv import load_dotenv

load_dotenv(override=True)

api_key = os.getenv("API_KEY")

client = KrutrimClient(api_key=api_key)

try:
    delete_resp = client.highlvlvpc.delete_machine_image(
        image_krn="enter the image_krn",  
        
    )
    print(f"Image deleted successfully: {delete_resp}")
except Exception as e:
    print(f"Exception has occurred: {e}")



import os
from dotenv import load_dotenv
from krutrim_client import KrutrimClient

load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)

try:
    delete_response = client.kos.buckets.delete_bucket(
        bucket_krn="enter the bucket krn",
        x_region_id="enter the region" 
        # x_region possible values "In-Bangalore-1","In-Hyderabad-1"               
    )

    print(f"Bucket deleted successfully: {delete_response}")

except Exception as e:
    print(f"Error has occurred: {e}")





from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from krutrim_client._utils import PropertyInfo

__all__ = ["V1CreateParams"]


class V1CreateParams(TypedDict, total=False):
    description: Required[str]
    """Description for the security group."""

    name: Required[str]
    """Name of the security group."""

    type: str
    """Type of the security group (e.g., 'lb' for load balancer)."""

    vpcid: Required[str]
    """KRN of the VPC where the security group will be created."""

    k_customer_id: Required[Annotated[str, PropertyInfo(alias="K-Customer-ID")]]

    x_account_id: Required[Annotated[str, PropertyInfo(alias="x-account-id")]]




from typing import List, Optional
from datetime import datetime
from typing_extensions import TypeAlias

from ..._models import BaseModel

__all__ = ["HighlvlvpcSearchNetworksResponse", "HighlvlvpcSearchNetworksResponseItem"]


class HighlvlvpcSearchNetworksResponseItem(BaseModel):
    admin_state_up: Optional[bool] = None
    """The administrative state of the network (true for up, false for down)."""

    created_at: Optional[datetime] = None
    """Timestamp of when the network was created."""

    name: Optional[str] = None
    """Name of the network."""

    network_id: Optional[str] = None
    """The unique KRN of the network."""

    shared: Optional[bool] = None
    """Indicates whether this network is shared across projects."""

    status: Optional[str] = None
    """The status of the network (e.g., ACTIVE, DOWN, BUILD, ERROR)."""

    subnets: Optional[List[str]] = None
    """List of KRNs of subnets attached to this network."""

    updated_at: Optional[datetime] = None
    """Timestamp of when the network was last updated."""

    vpc_id: Optional[str] = None
    """KRN of the VPC this network belongs to."""


HighlvlvpcSearchNetworksResponse: TypeAlias = List[HighlvlvpcSearchNetworksResponseItem]




from __future__ import annotations

from typing import Optional
from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["HighlvlvpcSearchInstancesParams"]


class HighlvlvpcSearchInstancesParams(TypedDict, total=False):
    vpc_id: Required[str]
    """The KRN of the VPC to filter instances."""

    k_customer_id: Required[Annotated[str, PropertyInfo(alias="k-customer-id")]]

    x_account_id: Required[Annotated[str, PropertyInfo(alias="x-account-id")]]

    x_user_email: Required[Annotated[str, PropertyInfo(alias="x-user-email")]]

    limit: int
    """Maximum number of instances to return per page."""

    page: int
    """Page number for pagination."""

    ip_fixed: Optional[str]
    """Filter instances by fixed IP address."""

    ip_floating: Optional[str]
    """Filter instances by floating IP address."""

    krn: Optional[str]
    """Filter instances by their KRN."""

    name: Optional[str]
    """Filter instances by name (exact match or contains, depending on API)."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from krutrim_client._models import BaseModel

__all__ = ["SecurityGroupListByVpcResponse", "Item", "ItemRule"]


class ItemRule(BaseModel):
    direction: Optional[Literal["ingress", "egress"]] = None
    """The direction of the traffic (inbound or outbound)."""

    port_range_max: Optional[int] = FieldInfo(alias="portRangeMax", default=None)
    """The maximum port number in the range (inclusive)."""

    port_range_min: Optional[int] = FieldInfo(alias="portRangeMin", default=None)
    """The minimum port number in the range (inclusive)."""

    protocol: Optional[str] = None
    """The IP protocol name (e.g., "tcp", "udp", "icmp") or "any"."""

    remote: Optional[str] = None
    """
    The source (for ingress) or destination (for egress) CIDR IP range or another
    security group ID.
    """


class Item(BaseModel):
    id: Optional[str] = None
    """Unique identifier for the security group."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """The timestamp when the security group was created."""

    description: Optional[str] = None
    """A brief description of the security group's purpose."""

    name: Optional[str] = None
    """The name of the security group."""

    rules: Optional[List[ItemRule]] = None
    """A list of ingress and egress rules for the security group."""

    vpc_id: Optional[str] = FieldInfo(alias="vpcId", default=None)
    """The UUID of the VPC this security group belongs to."""


class SecurityGroupListByVpcResponse(BaseModel):
    items: Optional[List[Item]] = None
    """An array of security group objects."""

    limit: Optional[int] = None
    """The maximum number of records requested."""

    offset: Optional[int] = None
    """The number of records skipped."""

    total_count: Optional[int] = FieldInfo(alias="totalCount", default=None)
    """The total number of security groups matching the criteria."""



import os
from dotenv import load_dotenv
from krutrim_client import KrutrimClient

load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)


try:
    
    certificate = client.certs.with_raw_response.retrieve(
        cert_id = "Enter the Certificate Id"
    )

    
    print(f"{certificate.json()}")

except Exception as e:
    print(f"Error has occurred: {e}")


# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel

__all__ = ["V1PerformActionResponse"]


class V1PerformActionResponse(BaseModel):
    instance_krn: Optional[str] = None
    """The KRN of the instance on which the action was performed."""

    message: Optional[str] = None
    """A confirmation message."""

    status: Optional[str] = None
    """The current status of the instance or action."""

    task_id: Optional[str] = None
    """Optional task ID for tracking asynchronous operations."""



from __future__ import annotations

import httpx

from .asgV1 import (
    V1Resource,
    AsyncV1Resource,
    V1ResourceWithRawResponse,
    AsyncV1ResourceWithRawResponse,
    V1ResourceWithStreamingResponse,
    AsyncV1ResourceWithStreamingResponse,
)
from ...types import asg_get_asg_krn_by_vpc_params
from ..._types import Body, Query, Headers, NoneType, NotGiven, NOT_GIVEN
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options

__all__ = ["AsgResource", "AsyncAsgResource"]


class AsgResource(SyncAPIResource):
    @cached_property
    def v1(self) -> V1Resource:
        return V1Resource(self._client)

    @cached_property
    def with_raw_response(self) -> AsgResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/asg-python#accessing-raw-response-data-eg-headers
        """
        return AsgResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsgResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/asg-python#with_streaming_response
        """
        return AsgResourceWithStreamingResponse(self)

    def get_asg_krn_by_vpc(
        self,
        *,
        page: int,
        size: int,
        vpc_krn: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Get ASG KRN by VPC

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            "/v1/asg/get_asg_krn",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "page": page,
                        "size": size,
                        "vpc_krn": vpc_krn,
                    },
                    asg_get_asg_krn_by_vpc_params.AsgGetAsgKrnByVpcParams,
                ),
            ),
            cast_to=NoneType,
        )


class AsyncAsgResource(AsyncAPIResource):
    @cached_property
    def v1(self) -> AsyncV1Resource:
        return AsyncV1Resource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncAsgResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/asg-python#accessing-raw-response-data-eg-headers
        """
        return AsyncAsgResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAsgResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/asg-python#with_streaming_response
        """
        return AsyncAsgResourceWithStreamingResponse(self)

    async def get_asg_krn_by_vpc(
        self,
        *,
        page: int,
        size: int,
        vpc_krn: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Get ASG KRN by VPC

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/v1/asg/get_asg_krn",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "page": page,
                        "size": size,
                        "vpc_krn": vpc_krn,
                    },
                    asg_get_asg_krn_by_vpc_params.AsgGetAsgKrnByVpcParams,
                ),
            ),
            cast_to=NoneType,
        )


class AsgResourceWithRawResponse:
    def __init__(self, asg: AsgResource) -> None:
        self._asg = asg

        self.get_asg_krn_by_vpc = to_raw_response_wrapper(
            asg.get_asg_krn_by_vpc,
        )

    @cached_property
    def v1(self) -> V1ResourceWithRawResponse:
        return V1ResourceWithRawResponse(self._asg.v1)


class AsyncAsgResourceWithRawResponse:
    def __init__(self, asg: AsyncAsgResource) -> None:
        self._asg = asg

        self.get_asg_krn_by_vpc = async_to_raw_response_wrapper(
            asg.get_asg_krn_by_vpc,
        )

    @cached_property
    def v1(self) -> AsyncV1ResourceWithRawResponse:
        return AsyncV1ResourceWithRawResponse(self._asg.v1)


class AsgResourceWithStreamingResponse:
    def __init__(self, asg: AsgResource) -> None:
        self._asg = asg

        self.get_asg_krn_by_vpc = to_streamed_response_wrapper(
            asg.get_asg_krn_by_vpc,
        )

    @cached_property
    def v1(self) -> V1ResourceWithStreamingResponse:
        return V1ResourceWithStreamingResponse(self._asg.v1)


class AsyncAsgResourceWithStreamingResponse:
    def __init__(self, asg: AsyncAsgResource) -> None:
        self._asg = asg

        self.get_asg_krn_by_vpc = async_to_streamed_response_wrapper(
            asg.get_asg_krn_by_vpc,
        )

    @cached_property
    def v1(self) -> AsyncV1ResourceWithStreamingResponse:
        return AsyncV1ResourceWithStreamingResponse(self._asg.v1)


from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()

api_key = os.getenv("api_key")

client = KrutrimClient(api_key = api_key)

try:
    get_instance_info_list_resp = client.highlvlvpc.list_instance_info(
        vpc_id = "Enter the VPC ID",
        x_region = "Enter the region",
        # x_region possible values "In-Bangalore-1","In-Hyderabad-1"
    )
    print(f"Successfully fetched the details {get_instance_info_list_resp}")
except Exception as e:
    print(f"Exception as occurred {e}")




from typing import List
from typing_extensions import TypeAlias

from .vpc_detail import VpcDetail

__all__ = ["HighlvlvpcListVpcsResponse"]

HighlvlvpcListVpcsResponse: TypeAlias = List[VpcDetail]




from __future__ import annotations

from typing import List, Union, Optional
from datetime import datetime
from typing_extensions import Literal

from .._resource import SyncAPIResource, AsyncAPIResource
from .._base_client import make_request_options
import httpx
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven, Base64FileInput

from ..types.securityGroup import (
    v1_create_security_group_params,
    create_security_group_rules_params,
    attach_security_group_rules_params,
    detach_security_group_rules_params,   

)
from ..types.securityGroup.v1_create_security_group_resp import V1CreateResponse
from ..types.securityGroup.create_security_group_rules_resp import V1CreateRuleResponse
from ..types.securityGroup.attach_detach_generic_response import GenericSuccessResponse

from ..types.securityGroup.security_group_list_by_vpc_response import SecurityGroupListByVpcResponse
from ..types.securityGroup import security_group_list_by_vpc_params



__all__ = ["SecurityGroupResource", "AsyncSecurityGroupResource"]

from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)

class SecurityGroupResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SecurityGroupResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.
        """
        return SecurityGroupResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SecurityGroupResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        """
        return SecurityGroupResourceWithStreamingResponse(self)
    


    def validate_create_security_group_parameters(
    self,
    description,
    name,
    vpcid,
    x_region,
    extra_headers=None,
    extra_query=None,
    extra_body=None,
    timeout=None
    ):
        if not isinstance(description, str):
            raise ValueError("'description' must be a string.")

        if not isinstance(name, str):
            raise ValueError("'name' must be a string.")

        if not isinstance(vpcid, str):
            raise ValueError("'vpcid' must be a string.")

        if extra_headers is not None and not isinstance(extra_headers, dict):
            raise ValueError("'extra_headers' must be a dictionary if provided.")

        if extra_query is not None and not isinstance(extra_query, dict):
            raise ValueError("'extra_query' must be a dictionary if provided.")

        if extra_body is not None and not isinstance(extra_body, dict):
            raise ValueError("'extra_body' must be a dictionary if provided.")

        if timeout not in (None, NOT_GIVEN) and not isinstance(timeout, (int, float, httpx.Timeout)):
            raise ValueError("'timeout' must be a float, int, or httpx.Timeout if provided.")

        if x_region not in ("In-Bangalore-1", "In-Hyderabad-1"):
            raise ValueError("'x_region' must be either 'In-Bangalore-1' or 'In-Hyderabad-1'.")


    def validate_create_rule_parameters(
    self,
    direction,
    ethertypes,
    port_max_range,
    port_min_range,
    protocol,
    remote_ip_prefix,
    vpcid,
    x_region,
    extra_headers=None,
    extra_query=None,
    extra_body=None,
    timeout=None
    ):
        if direction not in ("ingress", "egress"):
            raise ValueError("'direction' must be either 'ingress' or 'egress'.")

        if ethertypes not in ("ipv4", "ipv6"):
            raise ValueError("'ethertypes' must be either 'ipv4' or 'ipv6'.")

        if not isinstance(port_max_range, int):
            raise ValueError("'port_max_range' must be an integer.")

        if not isinstance(port_min_range, int):
            raise ValueError("'port_min_range' must be an integer.")

        if port_min_range < 0 or port_max_range < 0:
            raise ValueError("Port ranges must be non-negative integers.")

        if port_min_range > port_max_range:
            raise ValueError("'port_min_range' cannot be greater than 'port_max_range'.")

        if not isinstance(protocol, str):
            raise ValueError("'protocol' must be a string.")

        if not isinstance(remote_ip_prefix, str):
            raise ValueError("'remote_ip_prefix' must be a string.")

        if not isinstance(vpcid, str):
            raise ValueError("'vpcid' must be a string.")

        if extra_headers is not None and not isinstance(extra_headers, dict):
            raise ValueError("'extra_headers' must be a dictionary if provided.")

        if extra_query is not None and not isinstance(extra_query, dict):
            raise ValueError("'extra_query' must be a dictionary if provided.")

        if extra_body is not None and not isinstance(extra_body, dict):
            raise ValueError("'extra_body' must be a dictionary if provided.")

        if timeout not in (None, NOT_GIVEN) and not isinstance(timeout, (int, float, httpx.Timeout)):
            raise ValueError("'timeout' must be a float, int, or httpx.Timeout if provided.")

        if x_region not in ("In-Bangalore-1", "In-Hyderabad-1"):
            raise ValueError("'x_region' must be either 'In-Bangalore-1' or 'In-Hyderabad-1'.")

    def validate_attach_rule_parameters(
    self,
    ruleid,
    securityid,
    vpcid,
    x_region,
    extra_headers=None,
    extra_query=None,
    extra_body=None,
    timeout=None
    ):
        if not isinstance(ruleid, str) or not ruleid:
            raise ValueError("'ruleid' must be a non-empty string.")

        if not isinstance(securityid, str) or not securityid:
            raise ValueError("'securityid' must be a non-empty string.")

        if not isinstance(vpcid, str) or not vpcid:
            raise ValueError("'vpcid' must be a non-empty string.")

        if extra_headers is not None and not isinstance(extra_headers, dict):
            raise ValueError("'extra_headers' must be a dictionary if provided.")

        if extra_query is not None and not isinstance(extra_query, dict):
            raise ValueError("'extra_query' must be a dictionary if provided.")

        if extra_body is not None and not isinstance(extra_body, dict):
            raise ValueError("'extra_body' must be a dictionary if provided.")

        if timeout not in (None, NOT_GIVEN) and not isinstance(timeout, (int, float, httpx.Timeout)):
            raise ValueError("'timeout' must be a float, int, or httpx.Timeout if provided.")

        if x_region not in ("In-Bangalore-1", "In-Hyderabad-1"):
            raise ValueError("'x_region' must be either 'In-Bangalore-1' or 'In-Hyderabad-1'.")
        


    def validate_detach_rule_parameters(
    self,
    ruleid: str,
    securityid: str,
    vpcid: str,
    x_region,
    extra_headers=None,
    extra_query=None,
    extra_body=None,
    timeout=None
    ):
        # Validate ruleid
        if not isinstance(ruleid, str) or not ruleid.strip():
            raise ValueError("'ruleid' must be a non-empty string.")

        # Validate securityid
        if not isinstance(securityid, str) or not securityid.strip():
            raise ValueError("'securityid' must be a non-empty string.")

        # Validate vpcid
        if not isinstance(vpcid, str) or not vpcid.strip():
            raise ValueError("'vpcid' must be a non-empty string.")

        # Validate optional dictionary parameters
        for name, param in {
            "extra_headers": extra_headers,
            "extra_query": extra_query,
            "extra_body": extra_body,
        }.items():
            if param is not None and not isinstance(param, dict):
                raise ValueError(f"'{name}' must be a dictionary if provided.")

        # Validate timeout
        if timeout not in (None, NOT_GIVEN) and not isinstance(timeout, (int, float, httpx.Timeout)):
            raise ValueError("'timeout' must be a float, int, or httpx.Timeout if provided.")

        if x_region not in ("In-Bangalore-1", "In-Hyderabad-1"):
            raise ValueError("'x_region' must be either 'In-Bangalore-1' or 'In-Hyderabad-1'.")





    def create_security_group(
        self,
        *,
        description: str,
        name: str,
        vpcid: str,
        x_region: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> V1CreateResponse:
        """
        Create a new Security Group

        Args:
          description: Description for the security group.

          name: Name of the security group.

          type: Type of the security group (e.g., 'lb' for load balancer).

          vpcid: KRN of the VPC where the security group will be created.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        self.validate_create_security_group_parameters(
        description = description,
        name = name,
        vpcid = vpcid,
        extra_headers = extra_headers,
        extra_query = extra_query,
        extra_body = extra_body,
        timeout = timeout,
        x_region = x_region
        )
        extra_headers = {"x-region": x_region, **(extra_headers or {})}
        return self._post(
            "/securityGroup/v1",
            body=maybe_transform(
                {
                    "description": description,
                    "name": name,
                    "vpcid": vpcid,
                },
                v1_create_security_group_params.V1CreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1CreateResponse,
        ) 

    def list_by_vpc(
        self,
        vpc_krn_identifier: str,
        *,
        x_region: str,
        limit: int | NotGiven = NOT_GIVEN,
        offset: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SecurityGroupListByVpcResponse:
        """
        List security groups by VPC KRN identifier

        Args:
          limit: The maximum number of records to return (for pagination).

          offset: The number of records to skip from the beginning of the list (for pagination).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not vpc_krn_identifier:
            raise ValueError(f"Expected a non-empty value for `vpc_krn_identifier` but received {vpc_krn_identifier!r}")
        extra_headers = {"x-region": x_region, **(extra_headers or {})}
        return self._get(
            f"/securityGroup/v1/{vpc_krn_identifier}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {},
                    security_group_list_by_vpc_params.SecurityGroupListByVpcParams,
                ),
            ),
            cast_to=SecurityGroupListByVpcResponse,
        )
    

    # CREATE SECURTIY GROUP RULES
    def create_rule(
        self,
        *,
        direction: Literal["ingress", "egress"],
        ethertypes: Literal["ipv4", "ipv6"],
        port_max_range: int,
        port_min_range: int,
        protocol: str,
        remote_ip_prefix: str,
        vpcid: str,
        x_region : str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> V1CreateRuleResponse:
        """
        Create a new Security Group Rule

        Args:
          direction: Direction of the rule.

          ethertypes: Ethertype of the rule.

          port_max_range: Maximum port in the range.

          port_min_range: Minimum port in the range.

          protocol: Protocol for the rule (e.g., tcp, udp, icmp, or 'any').

          remote_ip_prefix: Remote IP CIDR prefix for the rule.

          vpcid: KRN of the VPC associated with the rule.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        self.validate_create_rule_parameters(
        direction = direction,
        ethertypes = ethertypes,
        port_max_range = port_max_range,
        port_min_range = port_min_range,
        protocol = protocol,
        remote_ip_prefix = remote_ip_prefix,
        vpcid = vpcid,
        extra_headers = extra_headers,
        extra_query = extra_query,
        extra_body = extra_body,
        timeout = timeout,
        x_region = x_region
        )
        extra_headers = {"x-region": x_region, **(extra_headers or {})}
        return self._post(
            "/securityGroup/v1/rule",
            body=maybe_transform(
                {
                    "direction": direction,
                    "ethertypes": ethertypes,
                    "port_max_range": port_max_range,
                    "port_min_range": port_min_range,
                    "protocol": protocol,
                    "remote_ip_prefix": remote_ip_prefix,
                    "vpcid": vpcid,
                },
                create_security_group_rules_params.V1CreateRuleParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1CreateRuleResponse,
        )


    # ATTACH SECURITY GROUP RULE
    def attach_rule(
        self,
        *,
        ruleid: str,
        securityid: str,
        vpcid: str,
        x_region: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GenericSuccessResponse:
        """
        Attach a rule to a Security Group

        Args:
          ruleid: KRN of the Security Group Rule.

          securityid: KRN of the Security Group to attach/detach the rule from.

          vpcid: KRN of the VPC associated with the Security Group and rule.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        self.validate_attach_rule_parameters(
        ruleid = ruleid,
        securityid = securityid,
        vpcid = vpcid,
        extra_headers= extra_headers,
        extra_query=extra_query,
        extra_body=extra_body,
        timeout=timeout,
        x_region = x_region
        )
        extra_headers = {"x-region": x_region, **(extra_headers or {})}
        return self._post(
            "/securityGroup/v1/attachrule",
            body=maybe_transform(
                {
                    "ruleid": ruleid,
                    "securityid": securityid,
                    "vpcid": vpcid,
                },
                attach_security_group_rules_params.V1AttachRuleParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=GenericSuccessResponse,
        )

    # DETACH SECURITY GROUP RULE
    def detach_rule(
        self,
        *,
        ruleid: str,
        securityid: str,
        vpcid: str,
        x_region: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GenericSuccessResponse:
        """
        Detach a rule from a Security Group

        Args:
          ruleid: KRN of the Security Group Rule.

          securityid: KRN of the Security Group to attach/detach the rule from.

          vpcid: KRN of the VPC associated with the Security Group and rule.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        self.validate_detach_rule_parameters(
                ruleid = ruleid,
                securityid = securityid,
                vpcid = vpcid,
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                x_region = x_region
        )
        extra_headers = {"x-region": x_region, **(extra_headers or {})}
        return self._post(
            "/securityGroup/v1/deattachrule",
            body=maybe_transform(
                {
                    "ruleid": ruleid,
                    "securityid": securityid,
                    "vpcid": vpcid,
                },
                detach_security_group_rules_params.V1DetachRuleParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=GenericSuccessResponse,
        )
    

    def delete_security_group(
        self,
        securitygroupid: str,
        *,
        x_region: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Delete a Security Group by ID

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not securitygroupid:
            raise ValueError(f"Expected a non-empty value for `securitygroupid` but received {securitygroupid!r}")
        extra_headers = {"x-region": x_region, **(extra_headers or {})}
        return self._delete(
            f"/securityGroup/v1/{securitygroupid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )    


    def delete_rule(
        self,
        securitygroupruleid: str,
        *,
        x_region : str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Delete a Security Group Rule by ID

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not securitygroupruleid:
            raise ValueError(
                f"Expected a non-empty value for `securitygroupruleid` but received {securitygroupruleid!r}"
            )
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers = {"x-region": x_region, **(extra_headers or {})}
        return self._delete(
            f"/securityGroup/v1/rule/{securitygroupruleid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )






class AsyncSecurityGroupResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSecurityGroupResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.
        """
        return AsyncSecurityGroupResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSecurityGroupResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.
        """
        return AsyncSecurityGroupResourceWithStreamingResponse(self)
    

    async def validate_create_security_group_parameters(
    self,
    description,
    name,
    vpcid,
    x_region,
    extra_headers=None,
    extra_query=None,
    extra_body=None,
    timeout=None
    ):
        if not isinstance(description, str):
            raise ValueError("'description' must be a string.")

        if not isinstance(name, str):
            raise ValueError("'name' must be a string.")

        if not isinstance(vpcid, str):
            raise ValueError("'vpcid' must be a string.")

        if extra_headers is not None and not isinstance(extra_headers, dict):
            raise ValueError("'extra_headers' must be a dictionary if provided.")

        if extra_query is not None and not isinstance(extra_query, dict):
            raise ValueError("'extra_query' must be a dictionary if provided.")

        if extra_body is not None and not isinstance(extra_body, dict):
            raise ValueError("'extra_body' must be a dictionary if provided.")

        if timeout not in (None, NOT_GIVEN) and not isinstance(timeout, (int, float, httpx.Timeout)):
            raise ValueError("'timeout' must be a float, int, or httpx.Timeout if provided.")

        if x_region not in ("In-Bangalore-1", "In-Hyderabad-1"):
            raise ValueError("'x_region' must be either 'In-Bangalore-1' or 'In-Hyderabad-1'.")


    async def validate_create_rule_parameters(
    self,
    direction,
    ethertypes,
    port_max_range,
    port_min_range,
    protocol,
    remote_ip_prefix,
    vpcid,
    x_region,
    extra_headers=None,
    extra_query=None,
    extra_body=None,
    timeout=None
    ):
        if direction not in ("ingress", "egress"):
            raise ValueError("'direction' must be either 'ingress' or 'egress'.")

        if ethertypes not in ("ipv4", "ipv6"):
            raise ValueError("'ethertypes' must be either 'ipv4' or 'ipv6'.")

        if not isinstance(port_max_range, int):
            raise ValueError("'port_max_range' must be an integer.")

        if not isinstance(port_min_range, int):
            raise ValueError("'port_min_range' must be an integer.")

        if port_min_range < 0 or port_max_range < 0:
            raise ValueError("Port ranges must be non-negative integers.")

        if port_min_range > port_max_range:
            raise ValueError("'port_min_range' cannot be greater than 'port_max_range'.")

        if not isinstance(protocol, str):
            raise ValueError("'protocol' must be a string.")

        if not isinstance(remote_ip_prefix, str):
            raise ValueError("'remote_ip_prefix' must be a string.")

        if not isinstance(vpcid, str):
            raise ValueError("'vpcid' must be a string.")

        if extra_headers is not None and not isinstance(extra_headers, dict):
            raise ValueError("'extra_headers' must be a dictionary if provided.")

        if extra_query is not None and not isinstance(extra_query, dict):
            raise ValueError("'extra_query' must be a dictionary if provided.")

        if extra_body is not None and not isinstance(extra_body, dict):
            raise ValueError("'extra_body' must be a dictionary if provided.")

        if timeout not in (None, NOT_GIVEN) and not isinstance(timeout, (int, float, httpx.Timeout)):
            raise ValueError("'timeout' must be a float, int, or httpx.Timeout if provided.")

        if x_region not in ("In-Bangalore-1", "In-Hyderabad-1"):
            raise ValueError("'x_region' must be either 'In-Bangalore-1' or 'In-Hyderabad-1'.")

    async def validate_attach_rule_parameters(
    self,
    ruleid,
    securityid,
    vpcid,
    x_region,
    extra_headers=None,
    extra_query=None,
    extra_body=None,
    timeout=None
    ):
        if not isinstance(ruleid, str) or not ruleid:
            raise ValueError("'ruleid' must be a non-empty string.")

        if not isinstance(securityid, str) or not securityid:
            raise ValueError("'securityid' must be a non-empty string.")

        if not isinstance(vpcid, str) or not vpcid:
            raise ValueError("'vpcid' must be a non-empty string.")

        if extra_headers is not None and not isinstance(extra_headers, dict):
            raise ValueError("'extra_headers' must be a dictionary if provided.")

        if extra_query is not None and not isinstance(extra_query, dict):
            raise ValueError("'extra_query' must be a dictionary if provided.")

        if extra_body is not None and not isinstance(extra_body, dict):
            raise ValueError("'extra_body' must be a dictionary if provided.")

        if timeout not in (None, NOT_GIVEN) and not isinstance(timeout, (int, float, httpx.Timeout)):
            raise ValueError("'timeout' must be a float, int, or httpx.Timeout if provided.")

        if x_region not in ("In-Bangalore-1", "In-Hyderabad-1"):
            raise ValueError("'x_region' must be either 'In-Bangalore-1' or 'In-Hyderabad-1'.")
        


    async def validate_detach_rule_parameters(
    self,
    ruleid: str,
    securityid: str,
    vpcid: str,
    x_region,
    extra_headers=None,
    extra_query=None,
    extra_body=None,
    timeout=None
    ):
        # Validate ruleid
        if not isinstance(ruleid, str) or not ruleid.strip():
            raise ValueError("'ruleid' must be a non-empty string.")

        # Validate securityid
        if not isinstance(securityid, str) or not securityid.strip():
            raise ValueError("'securityid' must be a non-empty string.")

        # Validate vpcid
        if not isinstance(vpcid, str) or not vpcid.strip():
            raise ValueError("'vpcid' must be a non-empty string.")

        # Validate optional dictionary parameters
        for name, param in {
            "extra_headers": extra_headers,
            "extra_query": extra_query,
            "extra_body": extra_body,
        }.items():
            if param is not None and not isinstance(param, dict):
                raise ValueError(f"'{name}' must be a dictionary if provided.")

        # Validate timeout
        if timeout not in (None, NOT_GIVEN) and not isinstance(timeout, (int, float, httpx.Timeout)):
            raise ValueError("'timeout' must be a float, int, or httpx.Timeout if provided.")

        if x_region not in ("In-Bangalore-1", "In-Hyderabad-1"):
            raise ValueError("'x_region' must be either 'In-Bangalore-1' or 'In-Hyderabad-1'.")


    

    async def create_security_group(
        self,
        *,
        description: str,
        name: str,
        vpcid: str,
        x_region: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> V1CreateResponse:
        """
        Create a new Security Group

        Args:
          description: Description for the security group.

          name: Name of the security group.

          type: Type of the security group (e.g., 'lb' for load balancer).

          vpcid: KRN of the VPC where the security group will be created.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        await self.validate_create_security_group_parameters(
            description = description,
            name = name,
            vpcid = vpcid,
            extra_headers = extra_headers,
            extra_query = extra_query,
            extra_body = extra_body,
            timeout = timeout,
            x_region = x_region
            )
        extra_headers = {"x-region": x_region, **(extra_headers or {})}
        return await self._post(
            "/securityGroup/v1",
            body=await async_maybe_transform(
                {
                    "description": description,
                    "name": name,
                    "vpcid": vpcid,
                },
                v1_create_security_group_params.V1CreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1CreateResponse,
        )

    async def list_by_vpc(
        self,
        vpc_krn_identifier: str,
        *,
        x_region: str,
        limit: int | NotGiven = NOT_GIVEN,
        offset: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SecurityGroupListByVpcResponse:
        """
        List security groups by VPC KRN identifier

        Args:
          limit: The maximum number of records to return (for pagination).

          offset: The number of records to skip from the beginning of the list (for pagination).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not vpc_krn_identifier:
            raise ValueError(f"Expected a non-empty value for `vpc_krn_identifier` but received {vpc_krn_identifier!r}")
        extra_headers = {"x-region": x_region, **(extra_headers or {})}
        return await self._get(
            f"/securityGroup/v1/{vpc_krn_identifier}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {},
                    security_group_list_by_vpc_params.SecurityGroupListByVpcParams,
                ),
            ),
            cast_to=SecurityGroupListByVpcResponse,
        )


    async def create_rule(
        self,
        *,
        direction: Literal["ingress", "egress"],
        ethertypes: Literal["ipv4", "ipv6"],
        port_max_range: int,
        port_min_range: int,
        protocol: str,
        remote_ip_prefix: str,
        vpcid: str,
        x_region: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> V1CreateRuleResponse:
        """
        Create a new Security Group Rule

        Args:
          direction: Direction of the rule.

          ethertypes: Ethertype of the rule.

          port_max_range: Maximum port in the range.

          port_min_range: Minimum port in the range.

          protocol: Protocol for the rule (e.g., tcp, udp, icmp, or 'any').

          remote_ip_prefix: Remote IP CIDR prefix for the rule.

          vpcid: KRN of the VPC associated with the rule.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """

        await self.validate_create_rule_parameters(
            direction = direction,
            ethertypes = ethertypes,
            port_max_range = port_max_range,
            port_min_range = port_min_range,
            protocol = protocol,
            remote_ip_prefix = remote_ip_prefix,
            vpcid = vpcid,
            extra_headers = extra_headers,
            extra_query = extra_query,
            extra_body = extra_body,
            timeout = timeout,
            x_region = x_region
            )

        extra_headers = {"x-region": x_region, **(extra_headers or {})}
        return await self._post(
            "/securityGroup/v1/rule",
            body=await async_maybe_transform(
                {
                    "direction": direction,
                    "ethertypes": ethertypes,
                    "port_max_range": port_max_range,
                    "port_min_range": port_min_range,
                    "protocol": protocol,
                    "remote_ip_prefix": remote_ip_prefix,
                    "vpcid": vpcid,
                },
                create_security_group_rules_params.V1CreateRuleParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1CreateRuleResponse,
        )


    async def attach_rule(
        self,
        *,
        ruleid: str,
        securityid: str,
        vpcid: str,
        x_region: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GenericSuccessResponse:
        """
        Attach a rule to a Security Group

        Args:
          ruleid: KRN of the Security Group Rule.

          securityid: KRN of the Security Group to attach/detach the rule from.

          vpcid: KRN of the VPC associated with the Security Group and rule.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        await self.validate_attach_rule_parameters(
        ruleid = ruleid,
        securityid = securityid,
        vpcid = vpcid,
        extra_headers= extra_headers,
        extra_query=extra_query,
        extra_body=extra_body,
        timeout=timeout,
        x_region= x_region
        )
        extra_headers = {"x-region": x_region, **(extra_headers or {})}
        return await self._post(
            "/securityGroup/v1/attachrule",
            body= await async_maybe_transform(
                {
                    "ruleid": ruleid,
                    "securityid": securityid,
                    "vpcid": vpcid,
                },
                attach_security_group_rules_params.V1AttachRuleParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=GenericSuccessResponse,
        )


    async def detach_rule(
        self,
        *,
        ruleid: str,
        securityid: str,
        vpcid: str,
        x_region: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GenericSuccessResponse:
        """
        Detach a rule from a Security Group

        Args:
          ruleid: KRN of the Security Group Rule.

          securityid: KRN of the Security Group to attach/detach the rule from.

          vpcid: KRN of the VPC associated with the Security Group and rule.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        await self.validate_detach_rule_parameters(
                ruleid = ruleid,
                securityid = securityid,
                vpcid = vpcid,
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                x_region = x_region
        )
        extra_headers = {"x-region": x_region, **(extra_headers or {})}
        return await self._post(
            "/securityGroup/v1/deattachrule",
            body=await async_maybe_transform(
                {
                    "ruleid": ruleid,
                    "securityid": securityid,
                    "vpcid": vpcid,
                },
                detach_security_group_rules_params.V1DetachRuleParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=GenericSuccessResponse,
        )

    async def delete_security_group(
        self,
        securitygroupid: str,
        *,
        x_region: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Delete a Security Group by ID

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not securitygroupid:
            raise ValueError(f"Expected a non-empty value for `securitygroupid` but received {securitygroupid!r}")
        extra_headers = {"x-region": x_region, **(extra_headers or {})}
        return await self._delete(
            f"/securityGroup/v1/{securitygroupid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def delete_rule(
        self,
        securitygroupruleid: str,
        *,
        x_region: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Delete a Security Group Rule by ID

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not securitygroupruleid:
            raise ValueError(
                f"Expected a non-empty value for `securitygroupruleid` but received {securitygroupruleid!r}"
            )
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers = {"x-region": x_region, **(extra_headers or {})}
        return await self._delete(
            f"/securityGroup/v1/rule/{securitygroupruleid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class SecurityGroupResourceWithRawResponse:
    def __init__(self, securityGroup: SecurityGroupResource) -> None:
        self._securityGroup = securityGroup

        self.delete_security_group = to_raw_response_wrapper(
            securityGroup.delete_security_group,
        )
        
        self.create_security_group = to_raw_response_wrapper(
            securityGroup.create_security_group,
        )

        self.create_rule = to_raw_response_wrapper(
            securityGroup.create_rule,
        )

        self.attach_rule = to_raw_response_wrapper(
            securityGroup.attach_rule,
        )

        self.detach_rule = to_raw_response_wrapper(
            securityGroup.detach_rule,
        )

        self.list_by_vpc = to_raw_response_wrapper(
            securityGroup.list_by_vpc,
        )
        self.delete_rule = to_raw_response_wrapper(
            securityGroup.delete_rule,
        )
        




class AsyncSecurityGroupResourceWithRawResponse:
    def __init__(self, securityGroup: AsyncSecurityGroupResource) -> None:
        self._securityGroup = securityGroup

        self.delete_security_group = async_to_raw_response_wrapper(
            securityGroup.delete_security_group,
        )

        self.create_security_group = async_to_raw_response_wrapper(
            securityGroup.create_security_group,
        )

        self.create_rule = async_to_raw_response_wrapper(
            securityGroup.create_rule,
        )

        self.attach_rule = async_to_raw_response_wrapper(
            securityGroup.attach_rule,
        )

        self.detach_rule = async_to_raw_response_wrapper(
            securityGroup.detach_rule,
        )

        self.list_by_vpc = async_to_raw_response_wrapper(
            securityGroup.list_by_vpc,
        )
        self.delete_rule = async_to_raw_response_wrapper(
            securityGroup.delete_rule,
        )
        


class SecurityGroupResourceWithStreamingResponse:
    def __init__(self, securityGroup: SecurityGroupResource) -> None:
        self._securityGroup = securityGroup

        self.delete_security_group = to_streamed_response_wrapper(
            securityGroup.delete_security_group,
        )

        self.create_security_group = to_streamed_response_wrapper(
            securityGroup.create_security_group,
        )

        self.create_rule = to_streamed_response_wrapper(
            securityGroup.create_rule,
        )

        self.attach_rule = to_streamed_response_wrapper(
            securityGroup.attach_rule,
        )

        self.detach_rule = to_streamed_response_wrapper(
            securityGroup.detach_rule,
        )

        self.list_by_vpc = to_streamed_response_wrapper(
            securityGroup.list_by_vpc,
        )
        self.delete_rule = to_streamed_response_wrapper(
            securityGroup.delete_rule,
        )


class AsyncSecurityGroupResourceWithStreamingResponse:
    def __init__(self, securityGroup: AsyncSecurityGroupResource) -> None:
        self._securityGroup = securityGroup

        self.delete_security_group = async_to_streamed_response_wrapper(
            securityGroup.delete_security_group,
        )

        self.create_security_group = async_to_streamed_response_wrapper(
            securityGroup.create_security_group,
        )
        
        self.create_rule = async_to_streamed_response_wrapper(
            securityGroup.create_rule,
        )

        self.attach_rule = async_to_streamed_response_wrapper(
            securityGroup.attach_rule,
        )

        self.detach_rule = async_to_streamed_response_wrapper(
            securityGroup.detach_rule,
        )
        self.list_by_vpc = async_to_streamed_response_wrapper(
            securityGroup.list_by_vpc,
        )
        self.delete_rule = async_to_streamed_response_wrapper(
            securityGroup.delete_rule,
        )

        

    

    



import os
from dotenv import load_dotenv
from krutrim_client import KrutrimClient

load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)


try:

    add_certificate_tag_response = client.certs.tags.with_raw_response.addCertificateTag(
    path_cert_id = "Enter Certificate ID",
    tags = {
        "Enter Tag Name": "Enter Tag Value"
    }
    )

    
    print(f"{add_certificate_tag_response.json()}")

except Exception as e:
    print(f"Error has occurred: {e}")


import os
from dotenv import load_dotenv
from krutrim_client import KrutrimClient

load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)


try:
    delete_template = client.asg.v1.with_raw_response.delete_launch_template(
        template_id="Enter the Template ID",
        template_name="Enter the Template Name",
        version=1, #Select which version you want to delete
        x_region="Enter the Region"
    )

    print(f"{delete_template.json()}")

except Exception as e:
    print(f"Error has occurred: {e}")


# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .highlvl_get_full_tg_list_params import HighlvlGetFullTgListParams as HighlvlGetFullTgListParams
from .highlvl_get_tg_names_only_params import HighlvlGetTgNamesOnlyParams as HighlvlGetTgNamesOnlyParams
from .highlvl_create_target_group_params import HighlvlCreateTargetGroupParams as HighlvlCreateTargetGroupParams
from .highlvl_delete_target_group_params import HighlvlDeleteTargetGroupParams as HighlvlDeleteTargetGroupParams
from .highlvl_update_target_group_params import HighlvlUpdateTargetGroupParams as HighlvlUpdateTargetGroupParams
from .highlvl_update_load_balancer_params import HighlvlUpdateLoadBalancerParams as HighlvlUpdateLoadBalancerParams
from .highlvl_get_detailed_target_groups_params import (
    HighlvlGetDetailedTargetGroupsParams as HighlvlGetDetailedTargetGroupsParams,
)
from .highlvl_create_load_balancer_orchestration_params import (
    HighlvlCreateLoadBalancerOrchestrationParams as HighlvlCreateLoadBalancerOrchestrationParams,
)
from .highlvl_create_target_group_response import TargetGroupCreateResponse as TargetGroupCreateResponse
from .highlvl_create_lb_orchestration_response import LBOrchestrationResp as LBOrchestrationResp


from __future__ import annotations

import os
from typing import Any, Union, Mapping
from typing_extensions import Self, override

import httpx

from . import _exceptions
from ._qs import Querystring
from ._types import (
    NOT_GIVEN,
    Omit,
    Timeout,
    NotGiven,
    Transport,
    ProxiesTypes,
    RequestOptions,
)
from ._utils import is_given, get_async_library
from ._version import __version__
from .resources import highlvlvpc, kbs, securityGroup, startStopVM, sshkey
from .resources.kos import kos
from .resources.kpod import kpod
from .resources.lb import lb
from .resources.kks import kks
from .resources.v1 import v1
from .resources.v1 import record
from .resources.v1.zone import zone
from .resources.v1.zone import vpc
from .resources.kks.clusters import clusters
from .resources.kks.clusters import addons
from .resources.kks.clusters import node_groups

from .resources.kcm import certs
from .resources.kcm import tags
from .resources.asg import asg
from .resources.asg import asgV1
from ._streaming import Stream as Stream, AsyncStream as AsyncStream
from ._exceptions import APIStatusError, KrutrimClientError
from ._base_client import (
    DEFAULT_MAX_RETRIES,
    SyncAPIClient,
    AsyncAPIClient,
)

__all__ = [
    "Timeout",
    "Transport",
    "ProxiesTypes",
    "RequestOptions",
    "KrutrimClient",
    "AsyncKrutrimClient",
    "Client",
    "AsyncClient",
]


class KrutrimClient(SyncAPIClient):
    highlvlvpc: highlvlvpc.HighlvlvpcResource
    kbs: kbs.KbsResource
    securityGroup: securityGroup.SecurityGroupResource
    startStopVM: startStopVM.StartStopResource
    sshkey :sshkey.SshkeysResource
    kpod: kpod.KpodResource
    kos: kos.KosResource
    lb: lb.HighlvlResource
    kks: kks.KksResource
    v1: v1.V1Resource
    addons: addons.AddonsResource
    clusters: clusters.ClustersResource
    node_groups: node_groups.NodeGroupsResource  
    record: record.RecordResource
    vpc: vpc.VpcResource
    zone: zone.ZoneResource  
    certs: certs.CertsResource
    tags: tags.TagsResource
    asg: asg.AsgResource
    asgV1: asgV1.V1Resource

    
    with_raw_response: KrutrimClientWithRawResponse
    with_streaming_response: KrutrimClientWithStreamedResponse

    # client options
    api_key: str

    def __init__(
        self,
        *,
        api_key: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: Union[float, Timeout, None, NotGiven] = NOT_GIVEN,
        max_retries: int = DEFAULT_MAX_RETRIES,
        default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        # Configure a custom httpx client.
        # We provide a `DefaultHttpxClient` class that you can pass to retain the default values we use for `limits`, `timeout` & `follow_redirects`.
        # See the [httpx documentation](https://www.python-httpx.org/api/#client) for more details.
        http_client: httpx.Client | None = None,
        # Enable or disable schema validation for data returned by the API.
        # When enabled an error APIResponseValidationError is raised
        # if the API responds with invalid data for the expected schema.
        #
        # This parameter may be removed or changed in the future.
        # If you rely on this feature, please open a GitHub issue
        # outlining your use-case to help us decide if it should be
        # part of our public interface in the future.
        _strict_response_validation: bool = False,
    ) -> None:
        """Construct a new synchronous KrutrimClient client instance.

        This automatically infers the `api_key` argument from the `KRUTRIMCLIENT_API_KEY` environment variable if it is not provided.
        """
        if api_key is None:
            api_key = os.environ.get("KRUTRIMCLIENT_API_KEY")
        if api_key is None:
            raise KrutrimClientError(
                "The api_key client option must be set either by passing api_key to the client or by setting the KRUTRIMCLIENT_API_KEY environment variable"
            )
        self.api_key = api_key

        if base_url is None:
            base_url = os.environ.get("KRUTRIMCLIENT_BASE_URL")
        if base_url is None:
            base_url = f"https://cloud.olakrutrim.com"

        super().__init__(
            version=__version__,
            base_url=base_url,
            max_retries=max_retries,
            timeout=timeout,
            http_client=http_client,
            custom_headers=default_headers,
            custom_query=default_query,
            _strict_response_validation=_strict_response_validation,
        )

        self.highlvlvpc = highlvlvpc.HighlvlvpcResource(self)
        self.kbs =  kbs.KbsResource(self)
        self.securityGroup = securityGroup.SecurityGroupResource(self)
        self.startStopVM = startStopVM.StartStopResource(self)
        self.sshkey = sshkey.SshkeysResource(self)
        self.kpod = kpod.KpodResource(self)
        self.kos = kos.KosResource(self)
        self.lb = lb.HighlvlResource(self)
        self.certs = certs.CertsResource(self)
        self.tags = tags.TagsResource(self)
        self.asg = asg.AsgResource(self)
        self.asgV1 = asgV1.V1Resource(self)
        self.kks = kks.KksResource(self)
        self.v1 = v1.V1Resource(self)
        self.addons = addons.AddonsResource(self)    
        self.clusters = clusters.ClustersResource(self)
        self.node_groups = node_groups.NodeGroupsResource(self)
        self.record = record.RecordResource(self)
        self.zone = zone.ZoneResource(self)
        self.vpc = vpc.VpcResource(self)
        self.with_raw_response = KrutrimClientWithRawResponse(self)
        self.with_streaming_response = KrutrimClientWithStreamedResponse(self)
        

        

    @property
    @override
    def qs(self) -> Querystring:
        return Querystring(array_format="comma")

    @property
    @override
    def auth_headers(self) -> dict[str, str]:
        api_key = self.api_key
        return {"Authorization": f"Bearer {api_key}"}

    @property
    @override
    def default_headers(self) -> dict[str, str | Omit]:
        return {
            **super().default_headers,
            "X-Stainless-Async": "false",
            **self._custom_headers,
        }

    def copy(
        self,
        *,
        api_key: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = NOT_GIVEN,
        http_client: httpx.Client | None = None,
        max_retries: int | NotGiven = NOT_GIVEN,
        default_headers: Mapping[str, str] | None = None,
        set_default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        set_default_query: Mapping[str, object] | None = None,
        _extra_kwargs: Mapping[str, Any] = {},
    ) -> Self:
        """
        Create a new client instance re-using the same options given to the current client with optional overriding.
        """
        if default_headers is not None and set_default_headers is not None:
            raise ValueError("The `default_headers` and `set_default_headers` arguments are mutually exclusive")

        if default_query is not None and set_default_query is not None:
            raise ValueError("The `default_query` and `set_default_query` arguments are mutually exclusive")

        headers = self._custom_headers
        if default_headers is not None:
            headers = {**headers, **default_headers}
        elif set_default_headers is not None:
            headers = set_default_headers

        params = self._custom_query
        if default_query is not None:
            params = {**params, **default_query}
        elif set_default_query is not None:
            params = set_default_query

        http_client = http_client or self._client
        return self.__class__(
            api_key=api_key or self.api_key,
            base_url=base_url or self.base_url,
            timeout=self.timeout if isinstance(timeout, NotGiven) else timeout,
            http_client=http_client,
            max_retries=max_retries if is_given(max_retries) else self.max_retries,
            default_headers=headers,
            default_query=params,
            **_extra_kwargs,
        )

    # Alias for `copy` for nicer inline usage, e.g.
    # client.with_options(timeout=10).foo.create(...)
    with_options = copy

    @override
    def _make_status_error(
        self,
        err_msg: str,
        *,
        body: object,
        response: httpx.Response,
    ) -> APIStatusError:
        if response.status_code == 400:
            return _exceptions.BadRequestError(err_msg, response=response, body=body)

        if response.status_code == 401:
            return _exceptions.AuthenticationError(err_msg, response=response, body=body)

        if response.status_code == 403:
            return _exceptions.PermissionDeniedError(err_msg, response=response, body=body)

        if response.status_code == 404:
            return _exceptions.NotFoundError(err_msg, response=response, body=body)

        if response.status_code == 409:
            return _exceptions.ConflictError(err_msg, response=response, body=body)

        if response.status_code == 422:
            return _exceptions.UnprocessableEntityError(err_msg, response=response, body=body)

        if response.status_code == 429:
            return _exceptions.RateLimitError(err_msg, response=response, body=body)

        if response.status_code >= 500:
            return _exceptions.InternalServerError(err_msg, response=response, body=body)
        return APIStatusError(err_msg, response=response, body=body)


class AsyncKrutrimClient(AsyncAPIClient):
    highlvlvpc: highlvlvpc.AsyncHighlvlvpcResource
    kbs: kbs.AsyncKbsResource
    securityGroup: securityGroup.AsyncSecurityGroupResource
    startStopVM: startStopVM.AsyncStartStopResource
    sshkey: sshkey.AsyncSshkeysResource
    kpod: kpod.AsyncKpodResource
    kos: kos.AsyncKosResource 
    lb: lb.AsyncHighlvlResource
    certs: certs.AsyncCertsResource
    tags: tags.AsyncTagsResource
    asg: asg.AsyncAsgResource
    asgV1: asgV1.AsyncV1Resource
    Kks: kks.AsyncKksResource
    v1: v1.AsyncV1Resource
    clusters: clusters.AsyncClustersResource
    node_groups: node_groups.AsyncNodeGroupsResource
    addons: addons.AsyncAddonsResource
    record = record.AsyncRecordResource
    zone =  zone.AsyncZoneResource
    vpc = vpc.AsyncVpcResource  
    
    with_raw_response: AsyncKrutrimClientWithRawResponse
    with_streaming_response: AsyncKrutrimClientWithStreamedResponse

    # client options
    api_key: str

    def __init__(
        self,
        *,
        api_key: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: Union[float, Timeout, None, NotGiven] = NOT_GIVEN,
        max_retries: int = DEFAULT_MAX_RETRIES,
        default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        # Configure a custom httpx client.
        # We provide a `DefaultAsyncHttpxClient` class that you can pass to retain the default values we use for `limits`, `timeout` & `follow_redirects`.
        # See the [httpx documentation](https://www.python-httpx.org/api/#asyncclient) for more details.
        http_client: httpx.AsyncClient | None = None,
        # Enable or disable schema validation for data returned by the API.
        # When enabled an error APIResponseValidationError is raised
        # if the API responds with invalid data for the expected schema.
        #
        # This parameter may be removed or changed in the future.
        # If you rely on this feature, please open a GitHub issue
        # outlining your use-case to help us decide if it should be
        # part of our public interface in the future.
        _strict_response_validation: bool = False,
    ) -> None:
        """Construct a new async AsyncKrutrimClient client instance.

        This automatically infers the `api_key` argument from the `KRUTRIMCLOUD_Client_API_KEY` environment variable if it is not provided.
        """
        if api_key is None:
            api_key = os.environ.get("KRUTRIMCLIENT_API_KEY")
        if api_key is None:
            raise KrutrimClientError(
                "The api_key client option must be set either by passing api_key to the client or by setting the KRUTRIMCLIENT_API_KEY environment variable"
            )
        self.api_key = api_key

        if base_url is None:
            base_url = os.environ.get("KRUTRIMCLIENT_BASE_URL")
        if base_url is None:
            base_url = f"https://cloud.olakrutrim.com"

        super().__init__(
            version=__version__,
            base_url=base_url,
            max_retries=max_retries,
            timeout=timeout,
            http_client=http_client,
            custom_headers=default_headers,
            custom_query=default_query,
            _strict_response_validation=_strict_response_validation,
        )

        self.highlvlvpc = highlvlvpc.AsyncHighlvlvpcResource(self)
        self.kbs = kbs.AsyncKbsResource(self)
        self.securityGroup: securityGroup.AsyncSecurityGroupResource(self)
        self.startStopVM: startStopVM.AsyncStartStopResource(self)
        self.sshkey: sshkey.AsyncSshkeysResource(self)
        self.kpod = kpod.AsyncKpodResource(self)
        self.kos = kos.AsyncKosResource(self)
        self.lb = lb.AsyncHighlvlResource(self)
        self.certs = certs.AsyncCertsResource(self)
        self.tags = tags.AsyncTagsResource(self)
        self.asg = asg.AsyncAsgResource(self)
        self.asgV1 = asgV1.AsyncV1Resource(self)
        self.kks = kks.AsyncKksResource(self)
        self.v1 = v1.AsyncV1Resource(self)
        self.addons = addons.AsyncAddonsResource(self)
        self.clusters = clusters.AsyncClustersResource(self)
        self.node_groups = node_groups.AsyncNodeGroupsResource(self)
        self.record = record.AsyncRecordResource(self)
        self.vpc = vpc.AsyncVpcResource(self)
        self.zone = zone.AsyncZoneResource(self)
        self.with_raw_response = AsyncKrutrimClientWithRawResponse(self)
        self.with_streaming_response = AsyncKrutrimClientWithStreamedResponse(self)

    @property
    @override
    def qs(self) -> Querystring:
        return Querystring(array_format="comma")

    @property
    @override
    def auth_headers(self) -> dict[str, str]:
        api_key = self.api_key
        return {"Authorization": f"Bearer {api_key}"}

    @property
    @override
    def default_headers(self) -> dict[str, str | Omit]:
        return {
            **super().default_headers,
            "X-Stainless-Async": f"async:{get_async_library()}",
            **self._custom_headers,
        }

    def copy(
        self,
        *,
        api_key: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = NOT_GIVEN,
        http_client: httpx.AsyncClient | None = None,
        max_retries: int | NotGiven = NOT_GIVEN,
        default_headers: Mapping[str, str] | None = None,
        set_default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        set_default_query: Mapping[str, object] | None = None,
        _extra_kwargs: Mapping[str, Any] = {},
    ) -> Self:
        """
        Create a new client instance re-using the same options given to the current client with optional overriding.
        """
        if default_headers is not None and set_default_headers is not None:
            raise ValueError("The `default_headers` and `set_default_headers` arguments are mutually exclusive")

        if default_query is not None and set_default_query is not None:
            raise ValueError("The `default_query` and `set_default_query` arguments are mutually exclusive")

        headers = self._custom_headers
        if default_headers is not None:
            headers = {**headers, **default_headers}
        elif set_default_headers is not None:
            headers = set_default_headers

        params = self._custom_query
        if default_query is not None:
            params = {**params, **default_query}
        elif set_default_query is not None:
            params = set_default_query

        http_client = http_client or self._client
        return self.__class__(
            api_key=api_key or self.api_key,
            base_url=base_url or self.base_url,
            timeout=self.timeout if isinstance(timeout, NotGiven) else timeout,
            http_client=http_client,
            max_retries=max_retries if is_given(max_retries) else self.max_retries,
            default_headers=headers,
            default_query=params,
            **_extra_kwargs,
        )

    # Alias for `copy` for nicer inline usage, e.g.
    # client.with_options(timeout=10).foo.create(...)
    with_options = copy

    @override
    def _make_status_error(
        self,
        err_msg: str,
        *,
        body: object,
        response: httpx.Response,
    ) -> APIStatusError:
        if response.status_code == 400:
            return _exceptions.BadRequestError(err_msg, response=response, body=body)

        if response.status_code == 401:
            return _exceptions.AuthenticationError(err_msg, response=response, body=body)

        if response.status_code == 403:
            return _exceptions.PermissionDeniedError(err_msg, response=response, body=body)

        if response.status_code == 404:
            return _exceptions.NotFoundError(err_msg, response=response, body=body)

        if response.status_code == 409:
            return _exceptions.ConflictError(err_msg, response=response, body=body)

        if response.status_code == 422:
            return _exceptions.UnprocessableEntityError(err_msg, response=response, body=body)

        if response.status_code == 429:
            return _exceptions.RateLimitError(err_msg, response=response, body=body)

        if response.status_code >= 500:
            return _exceptions.InternalServerError(err_msg, response=response, body=body)
        return APIStatusError(err_msg, response=response, body=body)


class KrutrimClientWithRawResponse:
    def __init__(self, client: KrutrimClient) -> None:
        self.highlvlvpc = highlvlvpc.HighlvlvpcResourceWithRawResponse(client.highlvlvpc)
        self.kbs = kbs.KbsResourceWithRawResponse(client.kbs)
        self.securityGroup = securityGroup.SecurityGroupResourceWithRawResponse(client.securityGroup)
        self.startStopVM = startStopVM.StartStopResourceWithRawResponse(client.startStopVM)
        self.sshkey = sshkey.SshkeysResourceWithRawResponse(client.sshkey)
        self.kpod = kpod.KpodResourceWithRawResponse(client.kpod)
        self.kos =kos.KosResourceWithRawResponse(client.kos)
        self.lb = lb.HighlvlResourceWithRawResponse(client.lb)
        self.certs = certs.CertsResourceWithRawResponse(client.certs)
        self.tags = tags.TagsResourceWithRawResponse(client.tags)
        self.asg = asg.AsgResourceWithRawResponse(client.asg)
        self.asgV1 = asgV1.V1ResourceWithRawResponse(client.asgV1)

        self.kks = kks.KksResourceWithRawResponse(client.kks)
        self.v1 = v1.V1ResourceWithRawResponse(client.v1)
        self.addons = addons.AddonsResourceWithRawResponse(client.addons)
        self.clusters = clusters.ClustersResourceWithRawResponse(client.clusters)
        self.node_groups = node_groups.NodeGroupsResourceWithRawResponse(client.node_groups)   
        self.record = record.RecordResourceWithRawResponse(client.record)
        self.zone = zone.ZoneResourceWithRawResponse(client.zone)   
        self.vpc = vpc.VpcResourceWithRawResponse(client.vpc)

class AsyncKrutrimClientWithRawResponse:
    def __init__(self, client: AsyncKrutrimClient) -> None:
        self.highlvlvpc = highlvlvpc.AsyncHighlvlvpcResourceWithRawResponse(client.highlvlvpc)
        self.kbs = kbs.AsyncKbsResourceWithRawResponse(client.kbs)
        self.securityGroup = securityGroup.AsyncSecurityGroupResourceWithRawResponse(client.securityGroup)
        self.startStopVM = startStopVM.AsyncStartStopResourceWithRawResponse(client.startStopVM)
        self.sshkey = sshkey.AsyncSshkeysResourceWithRawResponse(client.sshkey)
        self.kpod = kpod.AsyncKpodResourceWithRawResponse(client.kpod)
        self.kos = kos.AsyncKosResourceWithRawResponse(client.kos)
        self.lb = lb.AsyncHighlvlResourceWithRawResponse(client.lb)
        self.certs = certs.AsyncCertsResourceWithRawResponse(client.certs)
        self.tags = tags.AsyncTagsResourceWithRawResponse(client.tags)
        self.asg = asg.AsyncAsgResourceWithRawResponse(client.asg)
        self.asgV1 = asgV1.AsyncV1ResourceWithRawResponse(client.asgV1)
        self.kks = kks.AsyncKksResourceWithRawResponse(client.kks)
        self.v1 = v1.AsyncV1ResourceWithRawResponse(client.v1)
        self.addons = addons.AsyncAddonsResourceWithRawResponse(client.addons)    
        self.clusters = clusters.AsyncClustersResourceWithRawResponse(client.clusters)
        self.node_groups = node_groups.AsyncNodeGroupsResourceWithRawResponse(client.node_groups)
        self.record = record.AsyncRecordResourceWithRawResponse(client.record)
        self.zone = zone.AsyncZoneResourceWithRawResponse(client.zone)
        self.vpc = vpc.AsyncVpcResourceWithRawResponse(client.vpc)


class KrutrimClientWithStreamedResponse:
    def __init__(self, client: KrutrimClient) -> None:
        self.highlvlvpc = highlvlvpc.HighlvlvpcResourceWithStreamingResponse(client.highlvlvpc)
        self.kbs = kbs.KbsResourceWithStreamingResponse(client.kbs)
        self.securityGroup = securityGroup.SecurityGroupResourceWithStreamingResponse(client.securityGroup)
        self.startStopVM = startStopVM.StartStopResourceWithStreamingResponse(client.startStopVM)
        self.sshkey = sshkey.SshkeysResourceWithStreamingResponse(client.sshkey)
        self.kpod = kpod.KpodResourceWithStreamingResponse(client.kpod)
        self.kos = kos.KosResourceWithStreamingResponse(client.kos)
        self.lb = lb.HighlvlResourceWithStreamingResponse(client.lb)
        self.certs = certs.CertsResourceWithStreamingResponse(client.certs)
        self.tags = tags.TagsResourceWithStreamingResponse(client.tags)
        self.asg = asg.AsgResourceWithStreamingResponse(client.asg)
        self.asgV1 = asgV1.V1ResourceWithStreamingResponse(client.asgV1)
        self.kks = kks.KksResourceWithStreamingResponse(client.kks)
        self.v1 = v1.V1ResourceWithStreamingResponse(client.v1)
        self.addons = addons.AddonsResourceWithStreamingResponse(client.addons)
        self.clusters = clusters.ClustersResourceWithStreamingResponse(client.clusters)
        self.node_groups = node_groups.NodeGroupsResourceWithStreamingResponse(client.node_groups)
        self.record = record.RecordResourceWithStreamingResponse(client.record)
        self.zone = zone.ZoneResourceWithStreamingResponse(client.zone)
        self.vpc = vpc.VpcResourceWithStreamingResponse(client.vpc)
        
        

class AsyncKrutrimClientWithStreamedResponse:
    def __init__(self, client: AsyncKrutrimClient) -> None:
        self.highlvlvpc = highlvlvpc.AsyncHighlvlvpcResourceWithStreamingResponse(client.highlvlvpc)
        self.kbs = kbs.AsyncKbsResourceWithStreamingResponse(client.kbs)
        self.securityGroup = securityGroup.AsyncSecurityGroupResourceWithStreamingResponse(client.securityGroup)
        self.startStopVM = startStopVM.AsyncStartStopResourceWithStreamingResponse(client.startStopVM)
        self.sshkey = sshkey.AsyncSshkeysResourceWithStreamingResponse(client.sshkey)
        self.kpod = kpod.AsyncKpodResourceWithStreamingResponse(client.kpod)
        self.kos = kos.AsyncKosResourceWithStreamingResponse(client.kos)
        self.lb = lb.AsyncHighlvlResourceWithStreamingResponse(client.lb)
        self.certs = certs.AsyncCertsResourceWithStreamingResponse(client.certs)
        self.tags = tags.AsyncTagsResourceWithStreamingResponse(client.tags)
        self.asg = asg.AsyncAsgResourceWithStreamingResponse(client.asg)
        self.asgV1 = asgV1.AsyncV1ResourceWithStreamingResponse(client.asgV1)
        self.kks = kks.AsyncKksResourceWithStreamingResponse(client.kks)
        self.v1 =  v1.AsyncV1ResourceWithStreamingResponse(client.v1)
        self.addons = addons.AsyncAddonsResourceWithStreamingResponse(client.addons)
        self.clusters = clusters.AsyncClustersResourceWithStreamingResponse(client.clusters)
        self.node_groups = node_groups.AsyncNodeGroupsResourceWithStreamingResponse(client.node_groups)
        self.record = record.AsyncRecordResourceWithStreamingResponse(client.record)
        self.zone = zone.AsyncZoneResourceWithStreamingResponse(client.zone)
        self.vpc = vpc.AsyncVpcResourceWithStreamingResponse(client.vpc)        

Client = KrutrimClient

AsyncClient = AsyncKrutrimClient



from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()

api_key = os.getenv("api_key")

client = KrutrimClient(api_key = api_key)

try: 
    delete_security_group_resp = client.securityGroup.delete_security_group(
        securitygroupid = "Enter the Secuiry Group ID",
        x_region = "Enter the region",
        # x_region possible values "In-Bangalore-1","In-Hyderabad-1"
    )

    print(f"Deleted Successfully")
except Exception as e:
    print(f"Error has occured:  {e}")


# highlvlvpc_delete_image_params.py
from __future__ import annotations
from typing_extensions import Required, TypedDict

__all__ = ["HighlvlvpcDeleteImageParams"]

class HighlvlvpcImageParams(TypedDict, total=False):
    image_krn: Required[str]
    """The full URN of the image to delete."""





# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .cluster_create_params import ClusterCreateParams as ClusterCreateParams
from .cluster_upgrade_params import ClusterUpgradeParams as ClusterUpgradeParams
